package com.afp.ordermanagement.model;

import lombok.Data;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.List;
import java.util.Objects;

@Data
@Document(collection = "orders")
public class Order {

    @Id
    private String id;

    private String userId;
    private String emailAddress;
    private String trackingCode;

    private enum Status {
        UNFULFILLED,
        FULFILLED,
        CANCELLED
    };

    private double createdAt;
    private double updatedAt;
    private List<Item> items;
    private Address address;

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (!(o instanceof Order)) return false;
        Order order = (Order) o;
        return Double.compare(order.getCreatedAt(), getCreatedAt()) == 0 && Double.compare(order.getUpdatedAt(), getUpdatedAt()) == 0 && getId().equals(order.getId()) && getUserId().equals(order.getUserId()) && getEmailAddress().equals(order.getEmailAddress()) && Objects.equals(getTrackingCode(), order.getTrackingCode()) && getItems().equals(order.getItems()) && getAddress().equals(order.getAddress());
    }

    @Override
    public int hashCode() {
        return Objects.hash(getId(), getUserId(), getEmailAddress(), getTrackingCode(), getCreatedAt(), getUpdatedAt(), getItems(), getAddress());
    }

    @Override
    public String toString() {
        return "Order{" +
                "id='" + id + '\'' +
                ", userId='" + userId + '\'' +
                ", emailAddress='" + emailAddress + '\'' +
                ", trackingCode='" + trackingCode + '\'' +
                ", createdAt=" + createdAt +
                ", updatedAt=" + updatedAt +
                ", items=" + items +
                ", address=" + address +
                '}';
    }
}
